class Chef
  class Provider::Firewall < Chef::Provider::LWRPBase
    include Firehol::Helpers

    provides :firewall

    def whyrun_supported?
      false
    end

    action :create do
      converge_by "install firehol package and start/enable service" do
        package "firehol"

        service "firehol" do
          action %i(start enable)
        end

        cookbook_file "/etc/default/firehol" do
          owner "root"
          group "root"
          mode "0600"
        end
      end
    end

    action :restart do
      interfaces = run_context.resource_collection.
        select { |item| item.is_a?(Chef::Resource::FirewallInterface) }.
        map { |resource| { name: resource.common_name, interface: resource.interface } }
      rules      = run_context.resource_collection.
        select { |item| item.is_a?(Chef::Resource::FirewallRule) }.
        map do |resource|
          {
            command:     resource.command,
            description: resource.description,
            interface:   resource.interface,
            service:     resource.service,
            type:        resource.type
          }
        end.
        group_by { |rule| rule[:interface] }
      services   = run_context.resource_collection.
        select { |item| item.is_a?(Chef::Resource::FirewallService) }.
        map do |resource|
          {
            name:         resource.service_name,
            client_ports: ports_to_s(resource.client_ports),
            server_ports: ports_to_s(resource.server_ports)
          }
        end
      routers    = run_context.resource_collection.
        select { |item| item.is_a?(Chef::Resource::FirewallRouter) }.
        map do |resource|
          {
            name:               resource.common_name,
            inface:             resource.inface,
            outface:            resource.outface,
            masquerade:         resource.masquerade,
            reverse_masquerade: resource.reverse_masquerade
          }
        end

      firehol_config = template "/etc/firehol/firehol.conf" do
        owner "root"
        group "root"
        mode "0600"
        variables  interfaces: interfaces,
                   routers:    routers,
                   rules:      rules,
                   services:   services,
                   version:    new_resource.version
        action :nothing
      end
      firehol_config.run_action(:create)

      if firehol_config.updated_by_last_action?
        firehol_service = service "firehol" do
          action :nothing
        end

        new_resource.notifies :restart, firehol_service, :delayed
        new_resource.updated_by_last_action(true)
      end
    end
  end
end
