#
# Cookbook Name:: chef-firehol
# Recipe:: default
#
# All rights reserved - Do Not Redistribute
#

firewall "firehol" do
  version 6
end

firewall_interface "world" do
  interface "any"
end

firewall_rule "accept ssh connections" do
  command   "accept"
  interface "world"
  service   "ssh"
  type      "server"
end

firewall_rule "allow outgoing connections" do
  command   "accept"
  interface "world"
  service   "all"
  type      "client"
end

firewall_service "mosh" do
  server_ports "udp/60000:61000"
end

firewall_service "minidlna" do
  server_ports tcp: %w(1900 8200),
               udp: %w(1900 5353 8200)
end

secondary_interface = node["network"]["interfaces"].
  keys.
  find { |interface| !["lo", node["network"]["default_interface"]].include? interface }

firewall_router "home2internet" do
  inface     secondary_interface
  outface    node["network"]["default_interface"]
  masquerade true
end

firewall_router "internet2home" do
  inface             node["network"]["default_interface"]
  outface            secondary_interface
  reverse_masquerade true
end

firewall_rule "home2internet ssh" do
  command   "accept"
  interface "home2internet"
  service   "ssh"
  type      "client"
end

firewall_rule "home2internet route" do
  command   "accept"
  interface "home2internet"
  service   "all"
  type      "route"
end

firewall_rule "internet2home all" do
  command   "accept"
  interface "internet2home"
  service   "all"
  type      "client"
end

firewall_rule "internet2home reject ident" do
  command   "reject with tcp-reset"
  interface "internet2home"
  service   "ident"
  type      "route"
end
